@@ -325,8 +325,9 @@ class ContainersController(base.Controller):
             container_dict['interactive'] = strutils.bool_from_string(
                 container_dict.get('interactive', False), strict=True)
         except ValueError:
-            raise exception.InvalidValue(_('Valid run or interactive values '
-                                           'are: true, false, True, False'))
+            bools = ', '.join(strutils.TRUE_STRINGS + strutils.FALSE_STRINGS)
+            raise exception.InvalidValue(_('Valid run or interactive '
+                                           'values are: %s') % bools)
 
         auto_remove = container_dict.pop('auto_remove', None)
         if auto_remove is not None:
@@ -335,8 +336,10 @@ class ContainersController(base.Controller):
                 container_dict['auto_remove'] = strutils.bool_from_string(
                     auto_remove, strict=True)
             except ValueError:
-                raise exception.InvalidValue(_('Auto_remove values are: '
-                                               'true, false, True, False'))
+                bools = ', '.join(strutils.TRUE_STRINGS +
+                                  strutils.FALSE_STRINGS)
+                raise exception.InvalidValue(_('Valid auto_remove '
+                                               'values are: %s') % bools)
 
         runtime = container_dict.pop('runtime', None)
         if runtime is not None:
@@ -355,12 +358,32 @@ class ContainersController(base.Controller):
         pci_req = self._create_pci_requests_for_sriov_ports(context,
                                                             requested_networks)
 
+        healthcheck = container_dict.pop('healthcheck', {})
+        if healthcheck:
+            api_utils.version_check('healthcheck', '1.22')
+            healthcheck['test'] = healthcheck.pop('cmd', '')
+            container_dict['healthcheck'] = healthcheck
+
         mounts = container_dict.pop('mounts', [])
         if mounts:
             api_utils.version_check('mounts', '1.11')
 
         requested_volumes = self._build_requested_volumes(context, mounts)
 
+        privileged = container_dict.pop('privileged', None)
+        if privileged is not None:
+            api_utils.version_check('privileged', '1.21')
+            policy.enforce(context, "container:create:privileged",
+                           action="container:create:privileged")
+            try:
+                container_dict['privileged'] = strutils.bool_from_string(
+                    privileged, strict=True)
+            except ValueError:
+                bools = ', '.join(strutils.TRUE_STRINGS +
+                                  strutils.FALSE_STRINGS)
+                raise exception.InvalidValue(_('Valid privileged values '
+                                               'are: %s') % bools)
+
         # Valiadtion accepts 'None' so need to convert it to None
         if container_dict.get('image_driver'):
             container_dict['image_driver'] = api_utils.string_or_none(
@@ -598,8 +621,14 @@ class ContainersController(base.Controller):
         if 'name' in patch:
             patch['name'] = str(patch['name'])
         context = pecan.request.context
-        compute_api = pecan.request.compute_api
-        container = compute_api.container_update(context, container, patch)
+        if 'memory' not in patch and 'cpu' not in patch:
+            for field, patch_val in patch.items():
+                if getattr(container, field) != patch_val:
+                    setattr(container, field, patch_val)
+            container.save(context)
+        else:
+            compute_api = pecan.request.compute_api
+            container = compute_api.container_update(context, container, patch)
         return view.format_container(context, pecan.request.host_url,
                                      container.as_dict())
 
@@ -665,19 +694,14 @@ class ContainersController(base.Controller):
             context.all_projects = True
         container = utils.get_container(container_ident)
         check_policy_on_container(container.as_dict(), "container:delete")
-        try:
-            force = strutils.bool_from_string(force, strict=True)
-        except ValueError:
-            bools = ', '.join(strutils.TRUE_STRINGS + strutils.FALSE_STRINGS)
-            raise exception.InvalidValue(_('Valid force values are: %s')
-                                         % bools)
         stop = kwargs.pop('stop', False)
         try:
+            force = strutils.bool_from_string(force, strict=True)
             stop = strutils.bool_from_string(stop, strict=True)
         except ValueError:
             bools = ', '.join(strutils.TRUE_STRINGS + strutils.FALSE_STRINGS)
-            raise exception.InvalidValue(_('Valid stop values are: %s')
-                                         % bools)
+            raise exception.InvalidValue(_('Valid force or stop values '
+                                           'are: %s') % bools)
         compute_api = pecan.request.compute_api
         if not force and not stop:
             utils.validate_container_state(container, 'delete')
@@ -688,14 +712,13 @@ class ContainersController(base.Controller):
             utils.validate_container_state(container, 'delete_force')
         elif stop:
             api_utils.version_check('stop', '1.12')
-            check_policy_on_container(container.as_dict(),
-                                      "container:stop")
             utils.validate_container_state(container,
                                            'delete_after_stop')
             if container.status == consts.RUNNING:
+                check_policy_on_container(container.as_dict(),
+                                          "container:stop")
                 LOG.debug('Calling compute.container_stop with %s '
-                          'before delete',
-                          container.uuid)
+                          'before delete', container.uuid)
                 compute_api.container_stop(context, container, 10)
         container.status = consts.DELETING
         if container.host:
@@ -1078,6 +1101,7 @@ class ContainersController(base.Controller):
     @pecan.expose('json')
     @exception.wrap_pecan_controller_exception
     @validation.validate_query_param(pecan.request, schema.network_attach)
+    @validation.validated(schema.network_attach)
     def network_attach(self, container_ident, **kwargs):
         """Attach a network to the container.
 
