@@ -439,8 +439,10 @@ def is_all_projects(search_opts):
     if all_projects:
         try:
             all_projects = strutils.bool_from_string(all_projects, True)
-        except ValueError as err:
-            raise exception.InvalidValue(six.text_type(err))
+        except ValueError:
+            bools = ', '.join(strutils.TRUE_STRINGS + strutils.FALSE_STRINGS)
+            raise exception.InvalidValue(_('Valid all_projects values are: %s')
+                                         % bools)
     else:
         all_projects = False
     return all_projects
@@ -521,9 +523,12 @@ def build_requested_networks(context, nets):
     if not requested_networks:
         # Find an available neutron net and create docker network by
         # wrapping the neutron net.
-        neutron_net = neutron_api.get_available_network()
-        requested_networks.append({'network': neutron_net['id'],
+        network = neutron_api.get_available_network()
+        requested_networks.append({'network': network['id'],
                                    'port': '',
+                                   'router:external':
+                                       network.get('router:external'),
+                                   'shared': network.get('shared'),
                                    'fixed_ip': '',
                                    'preserve_on_delete': False})
 
