@@ -12,7 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import itertools
+import math
 
 import six
 import time
@@ -68,8 +70,9 @@ class Manager(periodic_task.PeriodicTasks):
 
     def init_containers(self, context):
         containers = objects.Container.list_by_host(context, self.host)
+        local_containers, _ = self.driver.list(context)
         uuid_to_status_map = {container.uuid: container.status
-                              for container in self.driver.list(context)}
+                              for container in local_containers}
         for container in containers:
             current_status = uuid_to_status_map[container.uuid]
             self._init_container(context, container)
@@ -169,15 +172,30 @@ class Manager(periodic_task.PeriodicTasks):
     def _wait_for_volumes_available(self, context, volumes, container,
                                     timeout=60, poll_interval=1):
         start_time = time.time()
+        request_volumes = copy.deepcopy(volumes)
         try:
             volumes = itertools.chain(volumes)
             volume = next(volumes)
             while time.time() - start_time < timeout:
-                if self.driver.is_volume_available(context, volume):
+                status = self.driver.get_volume_status(context, volume)
+                if status == 'available':
                     volume = next(volumes)
+                if status == 'in-use':
+                    multiattach = self.driver.check_multiattach(context,
+                                                                volume)
+                    if multiattach:
+                        volume = next(volumes)
+                elif status == 'error':
+                    break
                 time.sleep(poll_interval)
         except StopIteration:
             return
+        for volume in request_volumes:
+            if volume.auto_remove:
+                try:
+                    self.driver.delete_volume(context, volume)
+                except Exception:
+                    LOG.exception("Failed to delete volume")
         msg = _("Volumes did not reach available status after"
                 "%d seconds") % (timeout)
         self._fail_container(context, container, msg, unset_host=True)
@@ -195,7 +213,8 @@ class Manager(periodic_task.PeriodicTasks):
             # FIXME(kiennt): This block is too complicated. We should find
             #                new efficient way to do the check.
             if not container.disk:
-                container.disk = max(base_device_size, CONF.default_disk)
+                container.disk = math.ceil(max(base_device_size,
+                                               CONF.default_disk))
                 return
             else:
                 if container.disk < base_device_size:
@@ -341,6 +360,7 @@ class Manager(periodic_task.PeriodicTasks):
         try:
             for volume in volumes:
                 volume.container_uuid = container.uuid
+                volume.host = self.host
                 self._attach_volume(context, volume)
         except Exception as e:
             with excutils.save_and_reraise_exception():
@@ -361,15 +381,29 @@ class Manager(periodic_task.PeriodicTasks):
                           "container %(container_id)s",
                           {'volume_id': volume.volume_id,
                            'container_id': volume.container_uuid})
+                if volume.auto_remove:
+                    try:
+                        self.driver.delete_volume(context, volume)
+                    except Exception:
+                        LOG.exception("Failed to delete volume %s.",
+                                      volume.volume_id)
                 volume.destroy()
 
     def _detach_volumes(self, context, container, reraise=True):
         volumes = objects.VolumeMapping.list_by_container(context,
                                                           container.uuid)
         for volume in volumes:
-            self._detach_volume(context, volume, reraise=reraise)
-            if volume.auto_remove:
-                self.driver.delete_volume(context, volume)
+            db_volumes = objects.VolumeMapping.list_by_volume(context,
+                                                              volume.volume_id
+                                                              )
+            volume_hosts = [db_volume.host for db_volume in db_volumes]
+
+            if volume_hosts.count(self.host) == 1:
+                self._detach_volume(context, volume, reraise=reraise)
+                if volume.auto_remove and len(volume_hosts) == 1:
+                    self.driver.delete_volume(context, volume)
+            else:
+                volume.destroy()
 
     def _detach_volume(self, context, volume, reraise=True):
         context = context.elevated()
