@@ -11,8 +11,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import socket
-
 from oslo_config import cfg
 
 docker_group = cfg.OptGroup(name='docker',
@@ -20,7 +18,7 @@ docker_group = cfg.OptGroup(name='docker',
 
 docker_opts = [
     cfg.StrOpt('docker_remote_api_version',
-               default='1.25',
+               default='1.26',
                help='Docker remote api version. Override it according to '
                     'specific docker api version in your environment.'),
     cfg.IntOpt('default_timeout',
@@ -46,8 +44,7 @@ docker_opts = [
                help='Location of TLS private key file for '
                     'securing docker api requests (tlskey).'),
     cfg.StrOpt('docker_remote_api_host',
-               default=socket.gethostname(),
-               sample_default='localhost',
+               default='$my_ip',
                help='Defines the remote api host for the docker daemon.'),
     cfg.StrOpt('docker_remote_api_port',
                default='2375',
@@ -56,6 +53,9 @@ docker_opts = [
                default=5,
                help='Timeout in seconds for executing a command in a docker '
                     'container.'),
+    cfg.StrOpt('docker_data_root',
+               default='/var/lib/docker',
+               help='Root directory of persistent Docker state.'),
 ]
 
 ALL_OPTS = (docker_opts)
