@@ -271,6 +271,7 @@ class DockerDriver(driver.ContainerDriver):
                 runtime = container.runtime or CONF.container_runtime
 
             host_config = {}
+            host_config['privileged'] = container.privileged
             host_config['runtime'] = runtime
             host_config['binds'] = binds
             kwargs['volumes'] = [b['bind'] for b in binds.values()]
@@ -300,6 +301,18 @@ class DockerDriver(driver.ContainerDriver):
             if container.disk:
                 disk_size = str(container.disk) + 'G'
                 host_config['storage_opt'] = {'size': disk_size}
+            # The time unit in docker of heath checking is us, and the unit
+            # of interval and timeout is seconds.
+            if container.healthcheck:
+                healthcheck = {}
+                healthcheck['test'] = container.healthcheck.get('test', '')
+                interval = container.healthcheck.get('interval', 0)
+                healthcheck['interval'] = interval * 10 ** 9
+                healthcheck['retries'] = int(container.healthcheck.
+                                             get('retries', 0))
+                timeout = container.healthcheck.get('timeout', 0)
+                healthcheck['timeout'] = timeout * 10 ** 9
+                kwargs['healthcheck'] = healthcheck
 
             kwargs['host_config'] = docker.create_host_config(**host_config)
             if image['tag']:
@@ -431,8 +444,7 @@ class DockerDriver(driver.ContainerDriver):
         return True
 
     def list(self, context):
-        id_to_container_map = {}
-        uuids = []
+        non_existent_containers = []
         with docker_utils.docker_client() as docker:
             docker_containers = docker.list_containers()
             id_to_container_map = {c['Id']: c
@@ -450,17 +462,12 @@ class DockerDriver(driver.ContainerDriver):
             container_id = container.container_id
             docker_container = id_to_container_map.get(container_id)
             if not container_id or not docker_container:
-                if container.auto_remove:
-                    container.status = consts.DELETED
-                    container.save(context)
-                else:
-                    self.heal_with_rebuilding_container(context,
-                                                        container)
+                non_existent_containers.append(container)
                 continue
 
             self._populate_container(container, docker_container)
 
-        return local_containers
+        return local_containers, non_existent_containers
 
     def heal_with_rebuilding_container(self, context, container):
         compute_api = zun_compute.API(context)
@@ -497,7 +504,7 @@ class DockerDriver(driver.ContainerDriver):
         return containers
 
     def update_containers_states(self, context, containers):
-        local_containers = self.list(context)
+        local_containers, non_existent_containers = self.list(context)
         if not local_containers:
             return
 
@@ -528,6 +535,14 @@ class DockerDriver(driver.ContainerDriver):
                 container.save(context)
                 LOG.info('Host of container %s changed from %s to %s',
                          container.uuid, old_host, container.host)
+        for container in non_existent_containers:
+            if container.host == cur_host:
+                if container.auto_remove:
+                    container.status = consts.DELETED
+                    container.save(context)
+                else:
+                    self.heal_with_rebuilding_container(context,
+                                                        container)
 
     def show(self, context, container):
         with docker_utils.docker_client() as docker:
@@ -984,8 +999,11 @@ class DockerDriver(driver.ContainerDriver):
     def delete_volume(self, context, volume_mapping):
         self.volume_driver.delete(context, volume_mapping)
 
-    def is_volume_available(self, context, volume_mapping):
-        return self.volume_driver.is_volume_available(context, volume_mapping)
+    def get_volume_status(self, context, volume_mapping):
+        return self.volume_driver.get_volume_status(context, volume_mapping)
+
+    def check_multiattach(self, context, volume_mapping):
+        return self.volume_driver.check_multiattach(context, volume_mapping)
 
     def _get_or_create_docker_network(self, context, network_api,
                                       neutron_net_id):
@@ -1043,8 +1061,15 @@ class DockerDriver(driver.ContainerDriver):
                     kv = l.split("=")
                     label = {kv[0]: kv[1]}
                     labels.update(label)
+            runtimes = []
+            if 'Runtimes' in info:
+                for key in info['Runtimes']:
+                    runtimes.append(key)
+            else:
+                runtimes = ['runc']
             return (total, running, paused, stopped, cpus,
-                    architecture, os_type, os, kernel_version, labels)
+                    architecture, os_type, os, kernel_version, labels,
+                    runtimes)
 
     def get_total_disk_for_container(self):
         try:
