@@ -170,6 +170,8 @@ class Container(Base):
     capsule_id = Column(Integer,
                         ForeignKey('capsule.id', ondelete='CASCADE'))
     started_at = Column(DateTime)
+    privileged = Column(Boolean, default=False)
+    healthcheck = Column(JSONEncodedDict)
 
 
 class VolumeMapping(Base):
@@ -195,6 +197,7 @@ class VolumeMapping(Base):
         foreign_keys=container_uuid,
         primaryjoin='and_(VolumeMapping.container_uuid==Container.uuid)')
     auto_remove = Column(Boolean, default=False)
+    host = Column(String(255), nullable=True)
 
 
 class ExecInstance(Base):
@@ -359,6 +362,7 @@ class ComputeNode(Base):
     disk_used = Column(Integer, nullable=False, default=0)
     disk_quota_supported = Column(Boolean, nullable=False, default=sql.false(),
                                   server_default=sql.false())
+    runtimes = Column(JSONEncodedList, nullable=True)
 
 
 class Capsule(Base):
