@@ -272,7 +272,7 @@ class KuryrNetwork(network.Network):
         if not container_id:
             container_id = container.container_id
 
-        addresses, _ = self.create_or_update_port(
+        addresses, original_port = self.create_or_update_port(
             container, network_name, requested_network, security_groups)
 
         ipv4_address = None
@@ -288,25 +288,64 @@ class KuryrNetwork(network.Network):
             kwargs['ipv4_address'] = ipv4_address
         if ipv6_address:
             kwargs['ipv6_address'] = ipv6_address
-        self.docker.connect_container_to_network(
-            container_id, network_name, **kwargs)
+        try:
+            self.docker.connect_container_to_network(
+                container_id, network_name, **kwargs)
+        except exception.DockerError:
+            with excutils.save_and_reraise_exception():
+                self.do_port_cleanup(addresses, original_port)
         return addresses
 
+    def do_port_cleanup(self, addresses, port):
+        preserve_flag = addresses[0].get('preserve_on_delete')
+        port_id = port.get('id')
+        if preserve_flag:
+            port_req_body = {'port': {'device_id': '', 'device_owner': ''}}
+            port_req_body['port'][BINDING_HOST_ID] = None
+            port_req_body['port']['mac_address'] = port.get('mac_address')
+            port_req_body['port'][BINDING_PROFILE] = \
+                port.get(BINDING_PROFILE, {})
+
+            try:
+                # Requires admin creds to set port bindings
+                admin_context = zun_context.get_admin_context()
+                neutron_api = neutron.NeutronAPI(admin_context)
+                neutron_api.update_port(port_id, port_req_body)
+            except exception.PortNotFound:
+                LOG.debug('Unable to unbind port %s as it no longer '
+                          'exists.', port_id)
+            except Exception:
+                LOG.exception("Unable to clear device ID for port '%s'",
+                              port_id)
+        else:
+            try:
+                self.neutron_api.delete_port(port_id)
+            except exception.PortNotFound:
+                LOG.debug('Unable to delete port %s as it no longer '
+                          'exists.', port_id)
+
     def disconnect_container_from_network(self, container, network_name,
                                           neutron_network_id=None):
         container_id = container.get_sandbox_id()
         if not container_id:
             container_id = container.container_id
 
-        neutron_ports = set()
-        all_ports = set()
+        addrs_list = []
         if container.addresses and neutron_network_id:
             addrs_list = container.addresses.get(neutron_network_id, [])
-            for addr in addrs_list:
-                all_ports.add(addr['port'])
-                if not addr['preserve_on_delete']:
-                    port_id = addr['port']
-                    neutron_ports.add(port_id)
+
+        self._disconnect_container_from_network(container_id, network_name,
+                                                addrs_list)
+
+    def _disconnect_container_from_network(self, container_id, network_name,
+                                           addrs_list):
+        neutron_ports = set()
+        all_ports = set()
+        for addr in addrs_list:
+            all_ports.add(addr['port'])
+            if not addr['preserve_on_delete']:
+                port_id = addr['port']
+                neutron_ports.add(port_id)
 
         try:
             if container_id:
@@ -318,14 +357,50 @@ class KuryrNetwork(network.Network):
                     if port_id in neutron_ports:
                         self.neutron_api.delete_port(port_id)
                     else:
-                        port_req_body = {'port': {'device_id': ""}}
-                        self.neutron_api.update_port(port_id, port_req_body)
+                        self._unbind_port(port_id)
                 except exceptions.PortNotFoundClient:
                     LOG.warning('Maybe your libnetwork distribution do not '
                                 'have patch https://review.openstack.org/#/c/'
                                 '441024/ or neutron tag extension does not '
                                 'supported or not enabled.')
 
+    def _unbind_port(self, port_id):
+        port_req_body = {'port': {'device_id': '', 'device_owner': ''}}
+        port_req_body['port'][BINDING_HOST_ID] = None
+        try:
+            port = self.neutron_api.get_neutron_port(port_id)
+        except exception.PortNotFound:
+            LOG.debug('Unable to show port %s as it no longer '
+                      'exists.', port_id)
+            return
+        except Exception:
+            # NOTE: In case we can't retrieve the binding:profile assume
+            # that they are empty
+            LOG.exception("Unable to get binding:profile for port '%s'",
+                          port_id)
+            port_profile = {}
+        else:
+            port_profile = port.get(BINDING_PROFILE, {})
+        # NOTE: We're doing this to remove the binding information
+        # for the physical device but don't want to overwrite the other
+        # information in the binding profile.
+        for profile_key in ('pci_vendor_info', 'pci_slot'):
+            if profile_key in port_profile:
+                del port_profile[profile_key]
+        port_req_body['port'][BINDING_PROFILE] = port_profile
+
+        try:
+            # Requires admin creds to set port bindings
+            admin_context = zun_context.get_admin_context()
+            neutron_api = neutron.NeutronAPI(admin_context)
+            neutron_api.update_port(port_id, port_req_body)
+        except exception.PortNotFound:
+            LOG.debug('Unable to unbind port %s as it no longer '
+                      'exists.', port_id)
+        except Exception:
+            LOG.exception("Unable to clear device ID for port '%s'",
+                          port_id)
+
     def add_security_groups_to_ports(self, container, security_group_ids):
         container_id = container.get_sandbox_id()
         if not container_id:
