@@ -54,6 +54,7 @@ class FakeVolumeMapping(object):
     container_path = 'fake_path'
     container_uuid = 'fake-cid'
     volume_id = 'fake-vid'
+    auto_remove = False
 
     def __init__(self):
         self.__class__.volumes = []
@@ -68,6 +69,10 @@ class FakeVolumeMapping(object):
     def list_by_container(cls, context, container_id):
         return cls.volumes
 
+    @classmethod
+    def list_by_volume(cls, context, volume_id):
+        return cls.volumes
+
 
 class TestManager(base.TestCase):
 
@@ -317,18 +322,19 @@ class TestManager(base.TestCase):
     @mock.patch.object(fake_driver, 'pull_image')
     @mock.patch.object(fake_driver, 'detach_volume')
     @mock.patch.object(fake_driver, 'attach_volume')
-    @mock.patch.object(fake_driver, 'is_volume_available')
+    @mock.patch.object(fake_driver, 'get_volume_status')
     @mock.patch.object(fake_driver, 'create')
     @mock.patch.object(fake_driver, 'start')
     def test_container_run(
             self, mock_start, mock_create,
-            mock_is_volume_available, mock_attach_volume,
+            mock_get_volume_status, mock_attach_volume,
             mock_detach_volume, mock_pull, mock_list_by_container, mock_save,
             mock_spawn_n, mock_event_finish, mock_event_start):
         container = Container(self.context, **utils.get_test_container())
         image = {'image': 'repo', 'path': 'out_path', 'driver': 'glance'}
         mock_create.return_value = container
         mock_pull.return_value = image, False
+        mock_get_volume_status.return_value = 'available'
         mock_spawn_n.side_effect = lambda f, *x, **y: f(*x, **y)
         container.status = 'Stopped'
         self.compute_manager._resource_tracker = FakeResourceTracker()
@@ -348,31 +354,38 @@ class TestManager(base.TestCase):
         mock_start.assert_called_once_with(self.context, container)
         mock_attach_volume.assert_called_once()
         mock_detach_volume.assert_not_called()
-        mock_is_volume_available.assert_called_once()
+        mock_get_volume_status.assert_called_once()
         self.assertEqual(1, len(FakeVolumeMapping.volumes))
 
+    @mock.patch.object(fake_driver, 'delete_volume')
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
+    @mock.patch.object(VolumeMapping, 'list_by_volume',
+                       side_effect=FakeVolumeMapping.list_by_volume)
     @mock.patch.object(VolumeMapping, 'list_by_container',
                        side_effect=FakeVolumeMapping.list_by_container)
     @mock.patch.object(fake_driver, 'pull_image')
     @mock.patch.object(fake_driver, 'detach_volume')
     @mock.patch.object(fake_driver, 'attach_volume')
-    @mock.patch.object(fake_driver, 'is_volume_available')
+    @mock.patch.object(fake_driver, 'get_volume_status')
     @mock.patch.object(fake_driver, 'create')
     @mock.patch.object(fake_driver, 'start')
     def test_container_run_driver_attach_failed(
             self, mock_start, mock_create,
-            mock_is_volume_available, mock_attach_volume,
-            mock_detach_volume, mock_pull, mock_list_by_container, mock_save,
-            mock_spawn_n, mock_event_finish, mock_event_start):
-        mock_is_volume_available.return_value = True
+            mock_get_volume_status, mock_attach_volume,
+            mock_detach_volume, mock_pull, mock_list_by_container,
+            mock_list_by_volume, mock_save,
+            mock_spawn_n, mock_event_finish, mock_event_start,
+            mock_delete_volume):
+        mock_get_volume_status.return_value = 'available'
         mock_attach_volume.side_effect = [None, base.TestingException("fake")]
         container = Container(self.context, **utils.get_test_container())
         vol = FakeVolumeMapping()
+        vol.auto_remove = True
         vol2 = FakeVolumeMapping()
+        vol2.auto_remove = True
         image = {'image': 'repo', 'path': 'out_path', 'driver': 'glance'}
         mock_create.return_value = container
         mock_pull.return_value = image, False
@@ -403,21 +416,25 @@ class TestManager(base.TestCase):
     @mock.patch.object(ContainerActionEvent, 'event_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
+    @mock.patch.object(VolumeMapping, 'list_by_volume',
+                       side_effect=FakeVolumeMapping.list_by_volume)
     @mock.patch.object(VolumeMapping, 'list_by_container',
                        side_effect=FakeVolumeMapping.list_by_container)
     @mock.patch.object(fake_driver, 'detach_volume')
     @mock.patch.object(fake_driver, 'attach_volume')
-    @mock.patch.object(fake_driver, 'is_volume_available')
+    @mock.patch.object(fake_driver, 'get_volume_status')
     @mock.patch.object(fake_driver, 'pull_image')
     def test_container_run_image_not_found(
-            self, mock_pull, mock_is_volume_available,
+            self, mock_pull, mock_get_volume_status,
             mock_attach_volume, mock_detach_volume,
-            mock_list_by_container, mock_save, mock_spawn_n, mock_event_finish,
+            mock_list_by_container, mock_list_by_volume,
+            mock_save, mock_spawn_n, mock_event_finish,
             mock_event_start):
         container_dict = utils.get_test_container(
             image='test:latest', image_driver='docker',
             image_pull_policy='ifnotpresent')
         container = Container(self.context, **container_dict)
+        mock_get_volume_status.return_value = 'available'
         mock_pull.side_effect = exception.ImageNotFound(
             message="Image Not Found")
         mock_spawn_n.side_effect = lambda f, *x, **y: f(*x, **y)
@@ -438,28 +455,32 @@ class TestManager(base.TestCase):
                                           'ifnotpresent', 'docker')
         mock_attach_volume.assert_called_once()
         mock_detach_volume.assert_called_once()
-        mock_is_volume_available.assert_called_once()
+        mock_get_volume_status.assert_called_once()
         self.assertEqual(0, len(FakeVolumeMapping.volumes))
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
+    @mock.patch.object(VolumeMapping, 'list_by_volume',
+                       side_effect=FakeVolumeMapping.list_by_volume)
     @mock.patch.object(VolumeMapping, 'list_by_container',
                        side_effect=FakeVolumeMapping.list_by_container)
     @mock.patch.object(fake_driver, 'detach_volume')
     @mock.patch.object(fake_driver, 'attach_volume')
-    @mock.patch.object(fake_driver, 'is_volume_available')
+    @mock.patch.object(fake_driver, 'get_volume_status')
     @mock.patch.object(fake_driver, 'pull_image')
     def test_container_run_image_pull_exception_raised(
-            self, mock_pull, mock_is_volume_available,
+            self, mock_pull, mock_get_volume_status,
             mock_attach_volume, mock_detach_volume,
-            mock_list_by_container, mock_save, mock_spawn_n, mock_event_finish,
+            mock_list_by_container, mock_list_by_volume,
+            mock_save, mock_spawn_n, mock_event_finish,
             mock_event_start):
         container_dict = utils.get_test_container(
             image='test:latest', image_driver='docker',
             image_pull_policy='ifnotpresent')
         container = Container(self.context, **container_dict)
+        mock_get_volume_status.return_value = 'available'
         mock_pull.side_effect = exception.ZunException(
             message="Image Not Found")
         mock_spawn_n.side_effect = lambda f, *x, **y: f(*x, **y)
@@ -480,28 +501,32 @@ class TestManager(base.TestCase):
                                           'ifnotpresent', 'docker')
         mock_attach_volume.assert_called_once()
         mock_detach_volume.assert_called_once()
-        mock_is_volume_available.assert_called_once()
+        mock_get_volume_status.assert_called_once()
         self.assertEqual(0, len(FakeVolumeMapping.volumes))
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
+    @mock.patch.object(VolumeMapping, 'list_by_volume',
+                       side_effect=FakeVolumeMapping.list_by_volume)
     @mock.patch.object(VolumeMapping, 'list_by_container',
                        side_effect=FakeVolumeMapping.list_by_container)
     @mock.patch.object(fake_driver, 'detach_volume')
     @mock.patch.object(fake_driver, 'attach_volume')
-    @mock.patch.object(fake_driver, 'is_volume_available')
+    @mock.patch.object(fake_driver, 'get_volume_status')
     @mock.patch.object(fake_driver, 'pull_image')
     def test_container_run_image_pull_docker_error(
-            self, mock_pull, mock_is_volume_available,
+            self, mock_pull, mock_get_volume_status,
             mock_attach_volume, mock_detach_volume,
-            mock_list_by_container, mock_save, mock_spawn_n, mock_event_finish,
+            mock_list_by_container, mock_list_by_volume,
+            mock_save, mock_spawn_n, mock_event_finish,
             mock_event_start):
         container_dict = utils.get_test_container(
             image='test:latest', image_driver='docker',
             image_pull_policy='ifnotpresent')
         container = Container(self.context, **container_dict)
+        mock_get_volume_status.return_value = 'available'
         mock_pull.side_effect = exception.DockerError(
             message="Docker Error occurred")
         mock_spawn_n.side_effect = lambda f, *x, **y: f(*x, **y)
@@ -522,29 +547,33 @@ class TestManager(base.TestCase):
                                           'ifnotpresent', 'docker')
         mock_attach_volume.assert_called_once()
         mock_detach_volume.assert_called_once()
-        mock_is_volume_available.assert_called_once()
+        mock_get_volume_status.assert_called_once()
         self.assertEqual(0, len(FakeVolumeMapping.volumes))
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
+    @mock.patch.object(VolumeMapping, 'list_by_volume',
+                       side_effect=FakeVolumeMapping.list_by_volume)
     @mock.patch.object(VolumeMapping, 'list_by_container',
                        side_effect=FakeVolumeMapping.list_by_container)
     @mock.patch.object(fake_driver, 'detach_volume')
     @mock.patch.object(fake_driver, 'attach_volume')
-    @mock.patch.object(fake_driver, 'is_volume_available')
+    @mock.patch.object(fake_driver, 'get_volume_status')
     @mock.patch.object(fake_driver, 'pull_image')
     @mock.patch.object(fake_driver, 'create')
     def test_container_run_create_raises_docker_error(
-            self, mock_create, mock_pull, mock_is_volume_available,
+            self, mock_create, mock_pull, mock_get_volume_status,
             mock_attach_volume, mock_detach_volume,
-            mock_list_by_container, mock_save, mock_spawn_n,
+            mock_list_by_container, mock_list_by_volume,
+            mock_save, mock_spawn_n,
             mock_event_finish, mock_event_start):
         container = Container(self.context, **utils.get_test_container())
         image = {'image': 'repo', 'path': 'out_path', 'driver': 'glance',
                  'repo': 'test', 'tag': 'testtag'}
         mock_pull.return_value = image, True
+        mock_get_volume_status.return_value = 'available'
         mock_create.side_effect = exception.DockerError(
             message="Docker Error occurred")
         mock_spawn_n.side_effect = lambda f, *x, **y: f(*x, **y)
@@ -568,7 +597,7 @@ class TestManager(base.TestCase):
             self.context, container, image, networks, volumes)
         mock_attach_volume.assert_called_once()
         mock_detach_volume.assert_called_once()
-        mock_is_volume_available.assert_called_once()
+        mock_get_volume_status.assert_called_once()
         self.assertEqual(0, len(FakeVolumeMapping.volumes))
 
     @mock.patch.object(FakeResourceTracker,
@@ -1289,19 +1318,37 @@ class TestManager(base.TestCase):
         self.assertIsNone(mock_event_finish.call_args[1]['exc_val'])
         self.assertIsNone(mock_event_finish.call_args[1]['exc_tb'])
 
-    @mock.patch.object(fake_driver, 'is_volume_available')
+    @mock.patch.object(fake_driver, 'get_volume_status')
     @mock.patch.object(manager.Manager, '_fail_container')
     def test_wait_for_volumes_available(self, mock_fail,
-                                        mock_is_volume_available):
-        mock_is_volume_available.return_value = True
+                                        mock_get_volume_status):
+        mock_get_volume_status.return_value = 'available'
         container = Container(self.context, **utils.get_test_container())
         volumes = [FakeVolumeMapping()]
         self.compute_manager._wait_for_volumes_available(self.context,
                                                          volumes,
                                                          container)
-        mock_is_volume_available.assert_called_once()
+        mock_get_volume_status.assert_called_once()
         mock_fail.assert_not_called()
 
+    @mock.patch.object(fake_driver, 'delete_volume')
+    @mock.patch.object(fake_driver, 'get_volume_status')
+    @mock.patch.object(manager.Manager, '_fail_container')
+    def test_wait_for_volumes_available_failed(self, mock_fail,
+                                               mock_get_volume_status,
+                                               mock_delete_volume):
+        mock_get_volume_status.return_value = 'error'
+        container = Container(self.context, **utils.get_test_container())
+        volume = FakeVolumeMapping()
+        volume.auto_remove = True
+        volumes = [volume]
+        self.assertRaises(exception.Conflict,
+                          self.compute_manager._wait_for_volumes_available,
+                          self.context, volumes, container, timeout=2)
+        self.assertTrue(mock_get_volume_status.called)
+        self.assertTrue(mock_fail.called)
+        self.assertTrue(mock_delete_volume.called)
+
     @mock.patch.object(Network, 'save')
     @mock.patch.object(fake_driver, 'create_network')
     def test_network_create(self, mock_create, mock_save):
