@@ -102,6 +102,11 @@ def get_test_container(**kwargs):
         'auto_heal': kwargs.get('auto_heal', False),
         'capsule_id': kwargs.get('capsule_id', 42),
         'started_at': kwargs.get('started_at'),
+        'privileged': kwargs.get('privileged', False),
+        'healthcheck': kwargs.get('healthcheck',
+                                  {"retries": "2", "timeout": 3,
+                                   "test": "stat /etc/passwd || exit 1",
+                                   "interval": 3}),
     }
 
 
@@ -146,6 +151,7 @@ def get_test_volume_mapping(**kwargs):
                                      '1aca1705-20f3-4506-8bc3-59685d86a357'),
         'connection_info': kwargs.get('connection_info', 'fake_info'),
         'auto_remove': kwargs.get('auto_remove', False),
+        'host': kwargs.get('host', 'fake_host'),
     }
 
 
@@ -361,6 +367,7 @@ def get_test_compute_node(**kwargs):
         'disk_total': kwargs.get('disk_total', 80),
         'disk_used': kwargs.get('disk_used', 20),
         'disk_quota_supported': kwargs.get('disk_quota_supported', False),
+        'runtimes': kwargs.get('runtimes', ['runc']),
     }
 
 
